@@ -18,6 +18,7 @@
 from datetime import datetime
 import sys
 import json
+import pipes
 
 if sys.version_info < (2, 6):
     has_str_format = False
@@ -502,5 +503,5 @@ def print_config(config, key=None):
     elif key:
         print '[ERROR] Key `{}` not found.'.format(key)
     else:
-        for param, value in config.items():
-            print u'{0}={1}'.format(param, value)
+        for key in sorted(config):
+            print u'{0}={1}'.format(key, pipes.quote(config.get(key) or ''))
